====================================
Correlative measures on spike trains
====================================

***********************
Spike train correlation
***********************

.. automodule:: elephant.spike_train_correlation


*************************
Spike train dissimilarity
*************************

.. automodule:: elephant.spike_train_dissimilarity


*********************
Spike train synchrony
*********************

.. automodule:: elephant.spike_train_synchrony


References
----------

.. bibliography:: ../bib/elephant.bib
   :labelprefix: cor
   :keyprefix: correlation-
   :style: unsrt

.. bibliography:: ../bib/elephant.bib
   :labelprefix: ds
   :keyprefix: dissimilarity-
   :style: unsrt

.. bibliography:: ../bib/elephant.bib
   :labelprefix: syn
   :keyprefix: synchrony-
   :style: unsrt
